<?php
/**
 * Smarty plugin
 * @package Smarty
 * @subpackage plugins
 */

/**
 * Smarty {assign_debug_info} function plugin
 *
 * Type:     function<br>
 * Name:     assign_debug_info<br>
 * Purpose:  assign debug info to the template<br>
 * @author Monte Ohrt <monte at ohrt dot com>
 * @param array unused in this plugin
 * 
 * @param Smarty
 */
function smarty_function_assign_debug_info($params, &$smarty)
{

    $debug_info = Smarty_Internal_Debug::get_debug_vars($smarty);
 
    $_assigned_vars = $debug_info->tpl_vars;
    @ksort($_assigned_vars);
 
    $_config_vars = $debug_info->config_vars;
    @ksort($_config_vars);

    $smarty->assign("_debug_config_keys", @array_keys($_config_vars));
    $smarty->assign("_debug_config_vals", @array_values($_config_vars));
    
    @array_walk(Smarty_Internal_Debug::$template_data, 'func_concat_array');

    $smarty->assign("_debug_keys", @array_keys($_assigned_vars));
    $smarty->assign("_debug_vals", @array_values($_assigned_vars));
    
    $smarty->assign("_debug_tpls", Smarty_Internal_Debug::$template_data);
}

/**
 * array_walk callback routine. Checks if the template is available for reading.
 * 
 * @param array $elem array element
 *  
 * @return array
 * @see    ____func_see____
 * @since  1.0.0
 */
function func_concat_array(&$elem, $key)
{
    global $smarty_skin_root_dir, $smarty_skin_dir, $alt_skin_info;

    $alt_skin_dir = $alt_skin_info['alt_skin_dir'];

    $common_info = explode($smarty_skin_dir . XC_DS, $elem['name']);
    $alt_info = explode($alt_skin_dir . XC_DS, $elem['name']);

    if (isset($common_info[1])) {
        $elem['filename'] = $smarty_skin_dir . XC_DS . $common_info[1];
    }
    else if (isset($alt_info[1])) {
        $elem['filename'] = $alt_skin_dir . XC_DS . $alt_info[1];
    }
    $elem['filename'] = str_replace($smarty_skin_root_dir . XC_DS, "", $elem['filename']);

    return $elem;
}

/* vim: set expandtab: */

?>
